#
# spec file for package libgsasl
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgsasl
Version:        1.8.0
Release:        lp152.3.5
Source:         ftp://ftp.gnu.org/gnu/gsasl/%{name}-%{version}.tar.gz
Summary:        Implementation of the SASL framework and a few common SASL mechanisms
License:        LGPL-2.1+ and GPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.gnu.org/software/gsasl/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  krb5-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libidn-devel
BuildRequires:  libntlm-devel
BuildRequires:  pkgconfig

%description
GNU SASL is an implementation of the Simple Authentication and
Security Layer framework and a few common SASL mechanisms. SASL is
used by network servers (e.g., IMAP, SMTP) to request authentication
from clients, and in clients to authenticate against servers. 

%package -n libgsasl7
Summary:        Implementation of the SASL framework and a few common SASL mechanisms
Group:          Development/Libraries/C and C++
%if 0%{?suse_version}
Recommends:     %{name}-lang
%endif
# Needed to make lang package installable
Provides:       %{name} = %{version}

%description -n libgsasl7
GNU SASL is an implementation of the Simple Authentication and
Security Layer framework and a few common SASL mechanisms. SASL is
used by network servers (e.g., IMAP, SMTP) to request authentication
from clients, and in clients to authenticate against servers.

%package devel
Summary:        Implementation of the SASL framework and a few common SASL mechanisms
Group:          Development/Libraries/C and C++
Requires:       libgsasl7 = %{version}

%description devel
GNU SASL is an implementation of the Simple Authentication and
Security Layer framework and a few common SASL mechanisms. SASL is
used by network servers (e.g., IMAP, SMTP) to request authentication
from clients, and in clients to authenticate against servers.

%lang_package

%prep
%setup -q

%build
%configure --disable-static --with-pic
make %{?_smp_mflags}

%install
%makeinstall
%find_lang %{name}
rm -f %{buildroot}%{_libdir}/*.la
%if 0%{?fdupes:1}
%fdupes %buildroot
%endif

%check
make check

%post -n libgsasl7 -p /sbin/ldconfig

%postun -n libgsasl7 -p /sbin/ldconfig

%files -n libgsasl7
%defattr (-, root, root)
%doc AUTHORS COPYING.LIB NEWS README THANKS
%{_libdir}/*.so.*

%files devel
%defattr (-, root, root)
%{_includedir}/gsas*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files lang -f %{name}.lang

%changelog
* Mon Apr  4 2016 kukuk@suse.de
- Remove unused buildrequires for libgssglue-devel
* Tue Oct 27 2015 meissner@suse.com
- run "make check"
* Mon Feb  9 2015 p.drouand@gmail.com
- Update to version 1.8.0
  * SAML20 support following RFC 6595.
  * OPENID20 support following RFC 6616.
  * Various cleanups, portability and other bug fixes.
    See the NEWS entries during the 1.7.x branch for details
- Use %%lang_package macro instead of manually defined -lang package
- Remove libgsasl-stdio.h.patch; fixed
- Remove fix-arm.patch; fixed
- Use download Url as source
* Thu May  2 2013 jengelh@inai.de
- "Recommends" is not understood by RHEL6ish
* Thu Mar 21 2013 dmueller@suse.com
- fix build on aarch64 by applying fix-arm.patch
* Mon Feb 11 2013 aj@suse.com
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Thu Aug 16 2012 agraf@suse.com
- fix-arm.patch: Add hack to fix compiling on ARM
* Mon Aug 13 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-3.0+
  contains numerous GPL-3.0+ licensed test files
* Sat Aug 11 2012 jengelh@inai.de
- Have package compile on RHEL6ish.
* Fri Jul 27 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Sun Mar 25 2012 jengelh@medozas.de
- Enable building against libntlm (now that it exists in factory)
* Sun Mar 25 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant spec sections
* Fri Jul  8 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Fri May 27 2011 vuntz@opensuse.org
- Update to version 1.6.1:
  + Add a Libs.private to libgsasl.pc.
  + Updated translations.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 1.6.0:
  + SCRAM: General fixes and support for SCRAM-SHA-1-PLUS with
    channel bindings.
  + GS2-KRB5: New mechanism GS2 with support for Kerberos V5.
  + GSSAPI/GS2-KRB5: Support for MIT Kerberos for Windows GSS-API
    library.
  + DIGEST-MD5: The server code now returns GSASL_OK after the
    final token.
  + Added property for tls-unique channel binding.
  + No longer require the same or newer libgcrypt it was built
    with.
  + Several doc improvements.
  + Update gnulib files.
- Use source services: download_url, recompress and set_Version.
* Thu Mar 25 2010 vuntz@opensuse.org
- Update to version 1.4.4:
  + SCRAM: Fix build error on platforms without strnlen.
- Changes from version 1.4.3:
  + SCRAM: Don't read out of bounds when parsing tokens.
* Tue Mar 16 2010 dimstar@opensuse.org
- Update to version 1.4.2:
  + SCRAM: Encode and decode username/authzid properly. Before any
    username/authzid that contained '=' or ',' would not work.
  + Fix typo in error message for
    GSASL_GSSAPI_ACCEPT_SEC_CONTEXT_ERROR.
  + Updated translations.
* Wed Feb 17 2010 dimstar@opensuse.org
- Update to version 1.4.1:
  + gsasl: Improve application data throughput
  + Improve MinGW builds
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 1.4.0:
  + Fix Visual Studio project files to work with SCRAM.
  + Properly increment libtool version to reflect newly added ABIs.
    This was accidentally forgotten in the last release.
  + Export gsasl_sha1 and gsasl_hmac_sha1 in linker version script.
    This was accidentally forgotten in the last release.
  + Fix crash in SCRAM-SHA-1 client when the application provides a
    value for GSASL_SCRAM_SALTED_PASSWORD.
  + Fix detection of libgcrypt during builds.
  + Updated translations.
  + Add libgcrypt-devel BuildRequires.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 1.3:
  + libgsasl: Implement SCRAM-SHA-1.
    New properties are GSASL_SCRAM_ITER, GSASL_SCRAM_SALT,
    andGSASL_SCRAM_SALTED_PASSWORD.
  + libgsasl: Add helper APIs for SHA-1 and HMAC-SHA-1.
    New functions are gsasl_sha1 and gsasl_hmac_sha1.
* Sun Jun 14 2009 vuntz@novell.com
- Update to version 1.2:
  + The library needs at most around 250 bytes of stack frame size.
    This is useful for embedded platforms with limited amount of
    RAM.
  + Obsolete gsasl_md5pwd_get_password rewritten to use modern API.
  + Include a copy of the GPLv3 license in the archive. Some parts,
    such as the gnulib self-tests, are licensed under the GPLv3.
    The library remains licensed under LGPLv2.1+ though.
- Package COPYING.LIB instead of COPYING: there's no GPLv3 file in
  the built package (the GPLv3 files are only in the tarball).
* Wed Jun 10 2009 dmueller@suse.de
- Add Requires for lang package to libgsasl7.
* Thu May  7 2009 vuntz@novell.com
- Review package.
- Update to version 1.1:
  + DIGEST-MD5 client: Add support for client integrity layer.
  + DIGEST-MD5: Decoding of integrity protected sessions now works
    better.
  + libgsasl: Add new property GSASL_QOPS.
  + libgsasl: Add new property GSASL_QOP.
  + DIGEST-MD5 client: Now queries application for QOP value
  + DIGEST-MD5 server: Now queries application for QOP values.
  + DIGEST-MD5 server: No longer advertises support for integrity
    by default.
  + libgsasl: Added C pre-processor expressions for version
    handling.
  + libgsasl: Use a LD version script on platforms where it is
    supported.
  + libgsasl: Compiled with -fvisibility=hidden by default if
    supported.
- Remove unneeded libxml2-devel BuildRequires.
- Add a note about libntlm that doesn't exist in openSUSE.
- Do not make libgsasl7 Provide/Obsolete libgsasl.
* Mon Mar 16 2009 novell@mirell.de
- initial SUSE package
